[Xfce4-commits] [xfce/xfdesktop] 01/01: Change default image style to zoomed

noreply at xfce.org noreply at xfce.org
Sun Apr 6 11:33:16 CEST 2014


This is an automated email from the git hooks/post-receive script.

eric pushed a commit to branch master
in repository xfce/xfdesktop.

commit 44fdba5491ad7684d0ca19c5ee80899b8e23c394
Author: Eric Koegel <eric.koegel at gmail.com>
Date:   Sat Apr 5 22:00:09 2014 +0300

    Change default image style to zoomed
---
 settings/main.c      |    7 ++++---
 src/xfce-backdrop.c  |    4 ++--
 src/xfce-workspace.c |    4 ++--
 3 files changed, 8 insertions(+), 7 deletions(-)

diff --git a/settings/main.c b/settings/main.c
index 7a80c19..de80eea 100644
--- a/settings/main.c
+++ b/settings/main.c
@@ -1264,8 +1264,9 @@ xfdesktop_settings_background_tab_change_bindings(AppearancePanel *panel,
             gint image_style;
             old_property = xfdesktop_settings_generate_old_binding_string(panel, "image-style");
 
-            /* default to stretched when trying to migrate */
-            image_style = xfconf_channel_get_int(channel, old_property, XFCE_BACKDROP_IMAGE_STRETCHED);
+            /* default to zoomed when trying to migrate (zoomed was part of how
+             * auto worked in 4.10)*/
+            image_style = xfconf_channel_get_int(channel, old_property, XFCE_BACKDROP_IMAGE_ZOOMED);
 
             /* xfce_translate_image_styles will do sanity checking */
             gtk_combo_box_set_active(GTK_COMBO_BOX(panel->image_style_combo),
@@ -1847,7 +1848,7 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
                      panel);
 
     /* Pick the first entries so something shows up */
-    gtk_combo_box_set_active(GTK_COMBO_BOX(panel->image_style_combo), XFCE_BACKDROP_IMAGE_STRETCHED);
+    gtk_combo_box_set_active(GTK_COMBO_BOX(panel->image_style_combo), XFCE_BACKDROP_IMAGE_ZOOMED);
     gtk_combo_box_set_active(GTK_COMBO_BOX(panel->color_style_combo), XFCE_BACKDROP_COLOR_SOLID);
 
     /* Use these settings for all workspaces checkbox */
diff --git a/src/xfce-backdrop.c b/src/xfce-backdrop.c
index 324680f..607c951 100644
--- a/src/xfce-backdrop.c
+++ b/src/xfce-backdrop.c
@@ -1565,8 +1565,8 @@ xfce_backdrop_loader_size_prepared_cb(GdkPixbufLoader *loader,
     TRACE("entering");
 
     if(backdrop->priv->image_style == XFCE_BACKDROP_IMAGE_INVALID) {
-        g_warning("Invalid image style, setting to XFCE_BACKDROP_IMAGE_STRETCHED");
-        backdrop->priv->image_style = XFCE_BACKDROP_IMAGE_STRETCHED;
+        g_warning("Invalid image style, setting to XFCE_BACKDROP_IMAGE_ZOOMED");
+        backdrop->priv->image_style = XFCE_BACKDROP_IMAGE_ZOOMED;
     }
 
     switch(backdrop->priv->image_style) {
diff --git a/src/xfce-workspace.c b/src/xfce-workspace.c
index c5e5633..c4fb2f2 100644
--- a/src/xfce-workspace.c
+++ b/src/xfce-workspace.c
@@ -583,9 +583,9 @@ xfce_workspace_migrate_backdrop_image_style(XfceWorkspace *workspace,
         xfce_workspace_set_xfconf_property_value(workspace, monitor, "image-style", &value);
         g_value_unset(&value);
     } else {
         /* If no value was ever set default to stretched */
         g_value_init(&value, G_TYPE_INT);
-        g_value_set_int(&value, XFCE_BACKDROP_IMAGE_STRETCHED);
+        g_value_set_int(&value, XFCE_BACKDROP_IMAGE_ZOOMED);
         xfce_workspace_set_xfconf_property_value(workspace, monitor, "image-style", &value);
         g_value_unset(&value);
     }
@@ -583,9 +583,9 @@ xfce_workspace_migrate_backdrop_image_style(XfceWorkspace *workspace,
         g_value_unset(&value);
     } else {
-        /* If no value was ever set default to stretched */
+        /* If no value was ever set default to zoomed */
         g_value_init(&value, G_TYPE_INT);

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the Xfce4-commits mailing list